# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.2.0

([Full Changelog](https://github.com/agoose77/gennaker-tools/compare/v0.1.6...aa7f7967572d33167af8aacbcc3f6079e8b3a1fa))

### Maintenance and upkeep improvements

- deps: Update jupyter-server/jupyter_releaser action to v1.10.2 [#20](https://github.com/agoose77/gennaker-tools/pull/20) ()
- deps: Update gha (major) [#19](https://github.com/agoose77/gennaker-tools/pull/19) ()
- deps: Update gha [#18](https://github.com/agoose77/gennaker-tools/pull/18) ()

### Other merged PRs

- feat: only log filename [#22](https://github.com/agoose77/gennaker-tools/pull/22) ([@agoose77](https://github.com/agoose77))
- fix: only print when actual reconciliation occurs [#21](https://github.com/agoose77/gennaker-tools/pull/21) ([@agoose77](https://github.com/agoose77))

### Contributors to this release

The following people contributed discussions, new ideas, code and documentation contributions, and review.
See [our definition of contributors](https://github-activity.readthedocs.io/en/latest/use/#how-does-this-tool-define-contributions-in-the-reports).

([GitHub contributors page for this release](https://github.com/agoose77/gennaker-tools/graphs/contributors?from=2026-01-11&to=2026-01-28&type=c))

@agoose77 ([activity](https://github.com/search?q=repo%3Aagoose77%2Fgennaker-tools+involves%3Aagoose77+updated%3A2026-01-11..2026-01-28&type=Issues))

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.6

([Full Changelog](https://github.com/agoose77/gennaker-tools/compare/v0.1.5...0403a7b883afedf5634d7446c88a8bc1b3a9d842))

### Bugs fixed

- fix: handle round-trip and null [#17](https://github.com/agoose77/gennaker-tools/pull/17) ([@agoose77](https://github.com/agoose77))

### Other merged PRs

- Fix: perform initial reconciliation [#16](https://github.com/agoose77/gennaker-tools/pull/16) ([@agoose77](https://github.com/agoose77))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/agoose77/gennaker-tools/graphs/contributors?from=2026-01-11&to=2026-01-11&type=c))

[@agoose77](https://github.com/search?q=repo%3Aagoose77%2Fgennaker-tools+involves%3Aagoose77+updated%3A2026-01-11..2026-01-11&type=Issues)

## 0.1.5

No merged PRs

## 0.1.4

([Full Changelog](https://github.com/agoose77/gennaker-tools/compare/v0.1.3...795450402276c565914c01971d096d93afac9662))

### Merged PRs

- fix: command ID [#15](https://github.com/agoose77/gennaker-tools/pull/15) ([@agoose77](https://github.com/agoose77))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/agoose77/gennaker-tools/graphs/contributors?from=2025-12-23&to=2026-01-10&type=c))

[@agoose77](https://github.com/search?q=repo%3Aagoose77%2Fgennaker-tools+involves%3Aagoose77+updated%3A2025-12-23..2026-01-10&type=Issues)

## 0.1.3

([Full Changelog](https://github.com/agoose77/gennaker-tools/compare/c2dd80b54b1294fd7c581c9f1ca9241b02338093...3c9e5e267bd3b2d002290e79e9949a370bdeac79))

### Maintenance and upkeep improvements

- deps: Update gha to v6 (major) [#12](https://github.com/agoose77/gennaker-tools/pull/12) ([@renovate](https://github.com/renovate))
- deps: Update dependency python to v3.14.1 [#11](https://github.com/agoose77/gennaker-tools/pull/11) ([@renovate](https://github.com/renovate))
- deps: Update gha (major) [#6](https://github.com/agoose77/gennaker-tools/pull/6) ([@renovate](https://github.com/renovate))
- deps: Update dependency python to v3.14.0 [#5](https://github.com/agoose77/gennaker-tools/pull/5) ([@renovate](https://github.com/renovate))

### Other merged PRs

- Fix: more release fixes [#14](https://github.com/agoose77/gennaker-tools/pull/14) ([@agoose77](https://github.com/agoose77))
- fix: release workflow [#13](https://github.com/agoose77/gennaker-tools/pull/13) ([@agoose77](https://github.com/agoose77))
- Fix: cleanup exit logic, and guard reconciliation loop [#10](https://github.com/agoose77/gennaker-tools/pull/10) ([@agoose77](https://github.com/agoose77))
- Feat: add support for CodeMirror snippets [#9](https://github.com/agoose77/gennaker-tools/pull/9) ([@agoose77](https://github.com/agoose77))
- Feat: add TOML settings synchronisation. [#8](https://github.com/agoose77/gennaker-tools/pull/8) ([@agoose77](https://github.com/agoose77))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/agoose77/gennaker-tools/graphs/contributors?from=2025-07-24&to=2025-12-23&type=c))

[@agoose77](https://github.com/search?q=repo%3Aagoose77%2Fgennaker-tools+involves%3Aagoose77+updated%3A2025-07-24..2025-12-23&type=Issues) | [@renovate](https://github.com/search?q=repo%3Aagoose77%2Fgennaker-tools+involves%3Arenovate+updated%3A2025-07-24..2025-12-23&type=Issues)

## 0.1.2

([Full Changelog](https://github.com/agoose77/gennaker-tools/compare/v0.1.1...b7c19f098d01aced82088abd2524a0f3b1377b04))

### Merged PRs

- fix: release workflow [#13](https://github.com/agoose77/gennaker-tools/pull/13) ([@agoose77](https://github.com/agoose77))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/agoose77/gennaker-tools/graphs/contributors?from=2025-12-23&to=2025-12-23&type=c))

[@agoose77](https://github.com/search?q=repo%3Aagoose77%2Fgennaker-tools+involves%3Aagoose77+updated%3A2025-12-23..2025-12-23&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/agoose77/gennaker-tools/compare/c2dd80b54b1294fd7c581c9f1ca9241b02338093...9ac2a1e40a03fbd9745d36bdac84bbd72bfedcc4))

### Maintenance and upkeep improvements

- deps: Update gha to v6 (major) [#12](https://github.com/agoose77/gennaker-tools/pull/12) ([@renovate](https://github.com/renovate))
- deps: Update dependency python to v3.14.1 [#11](https://github.com/agoose77/gennaker-tools/pull/11) ([@renovate](https://github.com/renovate))
- deps: Update gha (major) [#6](https://github.com/agoose77/gennaker-tools/pull/6) ([@renovate](https://github.com/renovate))
- deps: Update dependency python to v3.14.0 [#5](https://github.com/agoose77/gennaker-tools/pull/5) ([@renovate](https://github.com/renovate))

### Other merged PRs

- Fix: cleanup exit logic, and guard reconciliation loop [#10](https://github.com/agoose77/gennaker-tools/pull/10) ([@agoose77](https://github.com/agoose77))
- Feat: add support for CodeMirror snippets [#9](https://github.com/agoose77/gennaker-tools/pull/9) ([@agoose77](https://github.com/agoose77))
- Feat: add TOML settings synchronisation. [#8](https://github.com/agoose77/gennaker-tools/pull/8) ([@agoose77](https://github.com/agoose77))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/agoose77/gennaker-tools/graphs/contributors?from=2025-07-24&to=2025-12-23&type=c))

[@agoose77](https://github.com/search?q=repo%3Aagoose77%2Fgennaker-tools+involves%3Aagoose77+updated%3A2025-07-24..2025-12-23&type=Issues) | [@renovate](https://github.com/search?q=repo%3Aagoose77%2Fgennaker-tools+involves%3Arenovate+updated%3A2025-07-24..2025-12-23&type=Issues)
